---
Summary: Ignore any files in folders starting with .
Status: Done
---

# Description

If in the scrum folder, there's any folders starting with '.', don't enter them, try to load cards from them or enter folders underneath them.
